function [gribd] = readgrib_rec(file,irec);

% function [gribd] = readgrib_rec(file,irec);
%
% Read the specified record from a GRIB file.  This is basically
% just a MATLAB wrapper for the "wgrib" program.
%
% Input:
%    file : {string} name of an NCEP/ECMWF model grib file
%    irec : [1 x 1] {integer} record number
%
% Output:
%    gribd : [1 x N] {double} the requested grib data
%          
% Requires:  wgrib in your path.  wgrib is a C program run via the
%	     shell that pull fields out of the grib file in a format
%            that can be read by Matlab.
%

% Created: 15 Mar 2006, Scott Hannon
% Update: 24 Oct 2008, Scott Hannon - change temporary binary file
%    name from "dump" to "rec_<file>".
% Update: 28 Oct 2008, S.Hannon - use "mktemp" for tmp filename
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

addpath /asl/matlab/science

d = dir(file);
%recfile = ['/dev/shm/rec_' d.name];
recfile = mktemp(['rec_' d.name]);

% Clear keyboard buffer
! read -st 0

% Run wgrib and create temporary binary file
eval(['! /asl/opt/bin/wgrib -nh -bin -d ' int2str(irec) ' -o ' recfile ' ' file ' > /dev/null']);

% Read temporary binary file
fid = fopen(recfile,'r');
gribd = fread(fid,'single')';   
junk = fclose(fid);

% Remove temporary binary file
eval(['! rm ' recfile])

%%% end of function %%%
